#include <iostream>
#include <fstream>
#include <assert.h>
#include <vector>
#include <iostream>

const int MaxN = 2e5 + 5;

struct SegmentTreeNode
{
    int min, max;

    SegmentTreeNode() : min(MaxN), max(-MaxN) {}
    SegmentTreeNode(int val) : min(val), max(val) {}
    SegmentTreeNode(int min, int max) : min(min), max(max) {}

    friend SegmentTreeNode operator+(const SegmentTreeNode &a, const SegmentTreeNode &b)
    {
        return SegmentTreeNode(std::min(a.min, b.min), std::max(a.max, b.max));
    }

    friend SegmentTreeNode operator+(const SegmentTreeNode &a, int val)
    {
        if (a.min == MaxN)
            return SegmentTreeNode(val);
        return SegmentTreeNode(a.min + val, a.max + val);
    }
};

const SegmentTreeNode NeutralElement = SegmentTreeNode();
const SegmentTreeNode ZeroElement = SegmentTreeNode(0);

SegmentTreeNode tree[4 * MaxN];
int lazy[4 * MaxN];
int arr[MaxN];
int pref[MaxN];

struct LazySegmentTree
{
    int n;
    LazySegmentTree(int n, int *arr) : n(n)
    {
        std::fill(tree, tree + 4 * n + 5, ZeroElement);
        std::fill(lazy, lazy + 4 * n + 5, 0);
        build(1, 1, n, arr);
    }

    void build(int node, int left, int right, int *arr)
    {
        if (left == right)
        {
            tree[node] = SegmentTreeNode(arr[left]);
            return;
        }
        int mid = (left + right) / 2;
        build(2 * node, left, mid, arr);
        build(2 * node + 1, mid + 1, right, arr);
        tree[node] = tree[2 * node] + tree[2 * node + 1];
    }

    void push_down(int node, int left, int right)
    {
        if (left >= right)
            return;
        tree[2 * node] = tree[2 * node] + lazy[node];
        tree[2 * node + 1] = tree[2 * node + 1] + lazy[node];
        lazy[2 * node] += lazy[node];
        lazy[2 * node + 1] += lazy[node];
        lazy[node] = 0;
    }

    void update(int node, int left, int right, int l, int r, int val)
    {
        push_down(node, left, right);

        if (r < left || right < l)
            return;
        if (l <= left && right <= r)
        {
            tree[node] = tree[node] + val;
            lazy[node] += val;
            return;
        }

        int mid = (left + right) / 2;
        update(2 * node, left, mid, l, r, val);
        update(2 * node + 1, mid + 1, right, l, r, val);
        tree[node] = tree[2 * node] + tree[2 * node + 1];
    }

    void update(int l, int r, int val)
    {
        update(1, 1, n, l, r, val);
    }

    void set(int pos, int val)
    {
        update(1, 1, n, pos, pos, val);
    }

    SegmentTreeNode query(int node, int left, int right, int l, int r)
    {
        push_down(node, left, right);

        if (r < left || right < l)
            return NeutralElement;
        if (l <= left && right <= r)
            return tree[node];
        int mid = (left + right) / 2;

        return query(2 * node, left, mid, l, r) + query(2 * node + 1, mid + 1, right, l, r);
    }

    SegmentTreeNode query(int l, int r)
    {
        SegmentTreeNode ans = query(1, 1, n, std::max(l, 1), r);
        if (l == 0)
        {
            ans = ans + ZeroElement;
        }
        return ans;
    }

    int get(int pos)
    {
        return query(pos, pos).min;
    }
};

int char_to_int(char ch)
{
    if (ch == 'o')
        return 1;
    if (ch == '-')
        return 0;
    if (ch == 'x')
        return -1;
    return 0;
}

int main(int argc, char *argv[])
{
    const std::string FILENAME("trip");

    std::ifstream fin(FILENAME + ".in");
    std::ofstream fout(FILENAME + ".out");
    int n;
    fin >> n;

    for (int i = 1; i <= n; ++i)
    {
        char ch;
        fin >> ch;
        arr[i] = char_to_int(ch);

        pref[i] = pref[i - 1] + arr[i];
    }
    LazySegmentTree sgt(n, pref);

    int q;
    fin >> q;
    assert(1 <= q && q <= 2e5);
    int qc = q;
    while (q--)
    {
        int type;
        fin >> type;
        if (type == 1)
        {
            int position;
            char cvalue;
            fin >> position >> cvalue;
            int value = char_to_int(cvalue);

            assert(1 <= position && position <= n);
            assert(-1 <= value && value <= 1);

            int old_value = arr[position];
            int delta_value = value - old_value;
            arr[position] = value;

            sgt.update(position, n, delta_value);
        }
        else
        {
            int l1, r1, l2, r2, k;
            fin >> l1 >> r1 >> l2 >> r2 >> k;
            assert(1 <= type && type <= 2);
            assert(1 <= l1 && l1 <= r1 && r1 <= l2 && l2 <= r2 && r2 <= n);
            assert(-2e5 <= k && k <= 2e5);

            SegmentTreeNode left_range = sgt.query(l1 - 1, r1 - 1);
            SegmentTreeNode right_range = sgt.query(l2, r2);

            int min_diff = right_range.min - left_range.max;
            int max_diff = right_range.max - left_range.min;
            fout << (min_diff <= k && k <= max_diff) << '\n';
        }
    }
    fin.close();
    fout.close();

    return 0;
}